==> vala-0.1.0.tar.bz2: vala-0.1.0/vala/valadeclarationstatement.c <==
/* valadeclarationstatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valadeclarationstatement.h"
#include <vala/valalocalvariabledeclaration.h>
#include <vala/valasourcereference.h>
#include <vala/valadeclarationstatement.h>
#include <vala/valacodevisitor.h>

struct _ValaDeclarationStatementPrivate {
	ValaLocalVariableDeclaration* _declaration;
};
#define VALA_DECLARATION_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DECLARATION_STATEMENT, ValaDeclarationStatementPrivate))
enum  {
	VALA_DECLARATION_STATEMENT_DUMMY_PROPERTY,
	VALA_DECLARATION_STATEMENT_DECLARATION
};
static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_declaration_statement_parent_class = NULL;
static void vala_declaration_statement_dispose (GObject * obj);


/**
 * Creates a new declaration statement.
 *
 * @param decl   local variable declaration
 * @param source reference to source code
 * @return       newly created declaration statement
 */
ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaDeclarationStatement * self;
	g_return_val_if_fail (VALA_IS_LOCAL_VARIABLE_DECLARATION (decl), NULL);
	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
	__params = g_new0 (GParameter, 2);
	__params_it = __params;
	(__params_it->name = "declaration", g_value_init (&__params_it->value, VALA_TYPE_LOCAL_VARIABLE_DECLARATION), g_value_set_object (&__params_it->value, decl), __params_it++);
	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
	self = g_object_newv (VALA_TYPE_DECLARATION_STATEMENT, __params_it - __params, __params);
	return self;
}


static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaDeclarationStatement * self;
	self = VALA_DECLARATION_STATEMENT (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_node_accept (VALA_CODE_NODE (vala_declaration_statement_get_declaration (self)), visitor);
	vala_code_visitor_visit_declaration_statement (visitor, self);
}


ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self)
{
	g_return_val_if_fail (VALA_IS_DECLARATION_STATEMENT (self), NULL);
	return self->priv->_declaration;
}


void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value)
{
	ValaLocalVariableDeclaration* __temp1;
	g_return_if_fail (VALA_IS_DECLARATION_STATEMENT (self));
	__temp1 = NULL;
	self->priv->_declaration = (__temp1 = g_object_ref (value), (self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL))), __temp1);
}


static void vala_declaration_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaDeclarationStatement * self;
	self = VALA_DECLARATION_STATEMENT (object);
	switch (property_id) {
		case VALA_DECLARATION_STATEMENT_DECLARATION:
		g_value_set_object (value, vala_declaration_statement_get_declaration (self));
		break;
	}
}


static void vala_declaration_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaDeclarationStatement * self;
	self = VALA_DECLARATION_STATEMENT (object);
	switch (property_id) {
		case VALA_DECLARATION_STATEMENT_DECLARATION:
		vala_declaration_statement_set_declaration (self, g_value_get_object (value));
		break;
	}
}


static void vala_declaration_statement_class_init (ValaDeclarationStatementClass * klass)
{
	vala_declaration_statement_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaDeclarationStatementPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_declaration_statement_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_declaration_statement_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_declaration_statement_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_declaration_statement_real_accept;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "foo", "bar", VALA_TYPE_LOCAL_VARIABLE_DECLARATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_declaration_statement_init (ValaDeclarationStatement * self)
{
	self->priv = VALA_DECLARATION_STATEMENT_GET_PRIVATE (self);
}


static void vala_declaration_statement_dispose (GObject * obj)
{
	ValaDeclarationStatement * self;
	ValaDeclarationStatementClass * klass;
	GObjectClass * parent_class;
	self = VALA_DECLARATION_STATEMENT (obj);
	(self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL)));
	klass = VALA_DECLARATION_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_DECLARATION_STATEMENT));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_declaration_statement_get_type ()
{
	static GType vala_declaration_statement_type_id = 0;
	if (G_UNLIKELY (vala_declaration_statement_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaDeclarationStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_declaration_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDeclarationStatement), 0, (GInstanceInitFunc) vala_declaration_statement_init };
		vala_declaration_statement_type_id = g_type_register_static (VALA_TYPE_STATEMENT, "ValaDeclarationStatement", &g_define_type_info, 0);
	}
	return vala_declaration_statement_type_id;
}

==> vala-0.1.2.tar.bz2: vala-0.1.2/vala/valadeclarationstatement.c <==
/* valadeclarationstatement.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valadeclarationstatement.h"
#include <vala/valalocalvariabledeclaration.h>
#include <vala/valasourcereference.h>
#include <vala/valadeclarationstatement.h>
#include <vala/valacodevisitor.h>

struct _ValaDeclarationStatementPrivate {
	ValaLocalVariableDeclaration* _declaration;
};
#define VALA_DECLARATION_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DECLARATION_STATEMENT, ValaDeclarationStatementPrivate))
enum  {
	VALA_DECLARATION_STATEMENT_DUMMY_PROPERTY,
	VALA_DECLARATION_STATEMENT_DECLARATION
};
static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_declaration_statement_parent_class = NULL;
static ValaStatementIface* vala_declaration_statement_vala_statement_parent_iface = NULL;
static void vala_declaration_statement_dispose (GObject * obj);


/**
 * Creates a new declaration statement.
 *
 * @param decl   local variable declaration
 * @param source reference to source code
 * @return       newly created declaration statement
 */
ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaDeclarationStatement * self;
	g_return_val_if_fail (VALA_IS_LOCAL_VARIABLE_DECLARATION (decl), NULL);
	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "declaration", g_value_init (&__params_it->value, VALA_TYPE_LOCAL_VARIABLE_DECLARATION), g_value_set_object (&__params_it->value, decl), __params_it++);
	self = g_object_newv (VALA_TYPE_DECLARATION_STATEMENT, __params_it - __params, __params);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaDeclarationStatement * self;
	self = ((ValaDeclarationStatement*) base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_node_accept (VALA_CODE_NODE (vala_declaration_statement_get_declaration (self)), visitor);
	vala_code_visitor_visit_declaration_statement (visitor, self);
}


ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self)
{
	g_return_val_if_fail (VALA_IS_DECLARATION_STATEMENT (self), NULL);
	return self->priv->_declaration;
}


void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value)
{
	ValaLocalVariableDeclaration* __temp1;
	g_return_if_fail (VALA_IS_DECLARATION_STATEMENT (self));
	__temp1 = NULL;
	self->priv->_declaration = (__temp1 = g_object_ref (value), (self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL))), __temp1);
}


static void vala_declaration_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaDeclarationStatement * self;
	self = VALA_DECLARATION_STATEMENT (object);
	switch (property_id) {
		case VALA_DECLARATION_STATEMENT_DECLARATION:
		g_value_set_object (value, vala_declaration_statement_get_declaration (self));
		break;
	}
}


static void vala_declaration_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaDeclarationStatement * self;
	self = VALA_DECLARATION_STATEMENT (object);
	switch (property_id) {
		case VALA_DECLARATION_STATEMENT_DECLARATION:
		vala_declaration_statement_set_declaration (self, g_value_get_object (value));
		break;
	}
}


static void vala_declaration_statement_class_init (ValaDeclarationStatementClass * klass)
{
	vala_declaration_statement_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaDeclarationStatementPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_declaration_statement_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_declaration_statement_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_declaration_statement_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_declaration_statement_real_accept;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "foo", "bar", VALA_TYPE_LOCAL_VARIABLE_DECLARATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_declaration_statement_vala_statement_interface_init (ValaStatementIface * iface)
{
	vala_declaration_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
}


static void vala_declaration_statement_init (ValaDeclarationStatement * self)
{
	self->priv = VALA_DECLARATION_STATEMENT_GET_PRIVATE (self);
}


static void vala_declaration_statement_dispose (GObject * obj)
{
	ValaDeclarationStatement * self;
	ValaDeclarationStatementClass * klass;
	GObjectClass * parent_class;
	self = VALA_DECLARATION_STATEMENT (obj);
	(self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL)));
	klass = VALA_DECLARATION_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_DECLARATION_STATEMENT));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_declaration_statement_get_type (void)
{
	static GType vala_declaration_statement_type_id = 0;
	if (G_UNLIKELY (vala_declaration_statement_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaDeclarationStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_declaration_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDeclarationStatement), 0, (GInstanceInitFunc) vala_declaration_statement_init };
		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_declaration_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		vala_declaration_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDeclarationStatement", &g_define_type_info, 0);
		g_type_add_interface_static (vala_declaration_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
	}
	return vala_declaration_statement_type_id;
}
